pub fn execute_acyclic_baseline(compiled: &CompileOutput) -> ExecutionReportExpand description
Executes one acyclic belief pass over the compiled graph.
pub fn execute_acyclic_baseline(compiled: &CompileOutput) -> ExecutionReportExecutes one acyclic belief pass over the compiled graph.