pub fn execute_delta_propagation(
compiled: &CompileOutput,
changed_node_ids: &[String],
max_iterations: u32,
) -> DeltaPropagationReportExpand description
Recomputes only the regions affected by a delta and reports parity metadata.
pub fn execute_delta_propagation(
compiled: &CompileOutput,
changed_node_ids: &[String],
max_iterations: u32,
) -> DeltaPropagationReportRecomputes only the regions affected by a delta and reports parity metadata.