pub fn execute_message_passing_baseline(
compiled: &CompileOutput,
max_iterations: u32,
) -> ExecutionReportExpand description
Executes bounded message passing across the full compiled graph.
pub fn execute_message_passing_baseline(
compiled: &CompileOutput,
max_iterations: u32,
) -> ExecutionReportExecutes bounded message passing across the full compiled graph.