pub fn schedule_execution(
compiled: &CompileOutput,
budget: &ExecutionBudget,
) -> ScheduledExecutionExpand description
Chooses the execution lane that fits the supplied graph and budget.
pub fn schedule_execution(
compiled: &CompileOutput,
budget: &ExecutionBudget,
) -> ScheduledExecutionChooses the execution lane that fits the supplied graph and budget.