pub struct ConstraintMessage {
pub iteration: u32,
pub from_constraint_id: String,
pub to_node_id: String,
pub support_micros: u64,
}Fields
iteration: u32from_constraint_id: Stringto_node_id: Stringsupport_micros: u64Trait Implementations
Sourceimpl Clone for ConstraintMessage
impl Clone for ConstraintMessage
Sourcefn clone(&self) -> ConstraintMessage
fn clone(&self) -> ConstraintMessage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConstraintMessage
impl Debug for ConstraintMessage
Sourceimpl<'de> Deserialize<'de> for ConstraintMessage
impl<'de> Deserialize<'de> for ConstraintMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConstraintMessage
Sourceimpl JsonSchema for ConstraintMessage
impl JsonSchema for ConstraintMessage
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConstraintMessage
impl PartialEq for ConstraintMessage
Sourcefn eq(&self, other: &ConstraintMessage) -> bool
fn eq(&self, other: &ConstraintMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ConstraintMessage
impl Serialize for ConstraintMessage
impl StructuralPartialEq for ConstraintMessage