pub struct ConvergenceGovernance {
pub damping_factor_micros: u64,
pub residual_tolerance_micros: u64,
pub max_iterations: u32,
pub stop_rule: String,
pub escalation_rule: String,
}Fields
damping_factor_micros: u64residual_tolerance_micros: u64max_iterations: u32stop_rule: Stringescalation_rule: StringTrait Implementations
Sourceimpl Clone for ConvergenceGovernance
impl Clone for ConvergenceGovernance
Sourcefn clone(&self) -> ConvergenceGovernance
fn clone(&self) -> ConvergenceGovernance
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConvergenceGovernance
impl Debug for ConvergenceGovernance
Sourceimpl<'de> Deserialize<'de> for ConvergenceGovernance
impl<'de> Deserialize<'de> for ConvergenceGovernance
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConvergenceGovernance
Sourceimpl JsonSchema for ConvergenceGovernance
impl JsonSchema for ConvergenceGovernance
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConvergenceGovernance
impl PartialEq for ConvergenceGovernance
Sourcefn eq(&self, other: &ConvergenceGovernance) -> bool
fn eq(&self, other: &ConvergenceGovernance) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ConvergenceGovernance
impl Serialize for ConvergenceGovernance
impl StructuralPartialEq for ConvergenceGovernance