pub struct DeltaPropagationReport {
pub changed_node_ids: Vec<String>,
pub recomputed_node_ids: Vec<String>,
pub recomputed_region_ids: Vec<RegionId>,
pub invalidation_manifest: InvalidationManifest,
pub region_traces: Vec<RegionExecutionTrace>,
pub execution: ExecutionReport,
}Fields
changed_node_ids: Vec<String>recomputed_node_ids: Vec<String>recomputed_region_ids: Vec<RegionId>invalidation_manifest: InvalidationManifestregion_traces: Vec<RegionExecutionTrace>execution: ExecutionReportTrait Implementations
Sourceimpl Clone for DeltaPropagationReport
impl Clone for DeltaPropagationReport
Sourcefn clone(&self) -> DeltaPropagationReport
fn clone(&self) -> DeltaPropagationReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeltaPropagationReport
impl Debug for DeltaPropagationReport
Sourceimpl<'de> Deserialize<'de> for DeltaPropagationReport
impl<'de> Deserialize<'de> for DeltaPropagationReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeltaPropagationReport
Sourceimpl JsonSchema for DeltaPropagationReport
impl JsonSchema for DeltaPropagationReport
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeltaPropagationReport
impl PartialEq for DeltaPropagationReport
Sourcefn eq(&self, other: &DeltaPropagationReport) -> bool
fn eq(&self, other: &DeltaPropagationReport) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DeltaPropagationReport
impl Serialize for DeltaPropagationReport
impl StructuralPartialEq for DeltaPropagationReport