pub struct ExecutionBudget {
pub max_iterations: u32,
pub max_messages: usize,
pub max_nodes: usize,
pub allow_repair: bool,
}Fields
max_iterations: u32max_messages: usizemax_nodes: usizeallow_repair: boolTrait Implementations
Sourceimpl Clone for ExecutionBudget
impl Clone for ExecutionBudget
Sourcefn clone(&self) -> ExecutionBudget
fn clone(&self) -> ExecutionBudget
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutionBudget
impl Debug for ExecutionBudget
Sourceimpl Default for ExecutionBudget
impl Default for ExecutionBudget
Sourceimpl<'de> Deserialize<'de> for ExecutionBudget
impl<'de> Deserialize<'de> for ExecutionBudget
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExecutionBudget
Sourceimpl JsonSchema for ExecutionBudget
impl JsonSchema for ExecutionBudget
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExecutionBudget
impl PartialEq for ExecutionBudget
Sourcefn eq(&self, other: &ExecutionBudget) -> bool
fn eq(&self, other: &ExecutionBudget) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ExecutionBudget
impl Serialize for ExecutionBudget
impl StructuralPartialEq for ExecutionBudget