pub struct ExecutionCalibrationReport {
pub nuisance_node_ids: Vec<String>,
pub caution_markers: Vec<String>,
pub degraded: bool,
}Fields
nuisance_node_ids: Vec<String>caution_markers: Vec<String>degraded: boolTrait Implementations
Sourceimpl Clone for ExecutionCalibrationReport
impl Clone for ExecutionCalibrationReport
Sourcefn clone(&self) -> ExecutionCalibrationReport
fn clone(&self) -> ExecutionCalibrationReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutionCalibrationReport
impl Debug for ExecutionCalibrationReport
Sourceimpl<'de> Deserialize<'de> for ExecutionCalibrationReport
impl<'de> Deserialize<'de> for ExecutionCalibrationReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExecutionCalibrationReport
Sourceimpl JsonSchema for ExecutionCalibrationReport
impl JsonSchema for ExecutionCalibrationReport
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExecutionCalibrationReport
impl PartialEq for ExecutionCalibrationReport
Sourcefn eq(&self, other: &ExecutionCalibrationReport) -> bool
fn eq(&self, other: &ExecutionCalibrationReport) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExecutionCalibrationReport