pub struct ExecutionCertificateArtifact {
pub node_id: String,
pub certificate_kind: String,
pub supporting_constraint_count: usize,
}Fields
node_id: Stringcertificate_kind: Stringsupporting_constraint_count: usizeTrait Implementations
Sourceimpl Clone for ExecutionCertificateArtifact
impl Clone for ExecutionCertificateArtifact
Sourcefn clone(&self) -> ExecutionCertificateArtifact
fn clone(&self) -> ExecutionCertificateArtifact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutionCertificateArtifact
impl Debug for ExecutionCertificateArtifact
Sourceimpl<'de> Deserialize<'de> for ExecutionCertificateArtifact
impl<'de> Deserialize<'de> for ExecutionCertificateArtifact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExecutionCertificateArtifact
Sourceimpl JsonSchema for ExecutionCertificateArtifact
impl JsonSchema for ExecutionCertificateArtifact
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExecutionCertificateArtifact
impl PartialEq for ExecutionCertificateArtifact
Sourcefn eq(&self, other: &ExecutionCertificateArtifact) -> bool
fn eq(&self, other: &ExecutionCertificateArtifact) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExecutionCertificateArtifact