pub struct ExecutionWitnessArtifact {
pub node_id: String,
pub supporting_constraint_ids: Vec<String>,
pub belief_micros: u64,
}Fields
node_id: Stringsupporting_constraint_ids: Vec<String>belief_micros: u64Trait Implementations
Sourceimpl Clone for ExecutionWitnessArtifact
impl Clone for ExecutionWitnessArtifact
Sourcefn clone(&self) -> ExecutionWitnessArtifact
fn clone(&self) -> ExecutionWitnessArtifact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutionWitnessArtifact
impl Debug for ExecutionWitnessArtifact
Sourceimpl<'de> Deserialize<'de> for ExecutionWitnessArtifact
impl<'de> Deserialize<'de> for ExecutionWitnessArtifact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExecutionWitnessArtifact
Sourceimpl JsonSchema for ExecutionWitnessArtifact
impl JsonSchema for ExecutionWitnessArtifact
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExecutionWitnessArtifact
impl PartialEq for ExecutionWitnessArtifact
Sourcefn eq(&self, other: &ExecutionWitnessArtifact) -> bool
fn eq(&self, other: &ExecutionWitnessArtifact) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ExecutionWitnessArtifact
impl Serialize for ExecutionWitnessArtifact
impl StructuralPartialEq for ExecutionWitnessArtifact