pub struct InvalidationManifest {
pub trigger: RecomputeTrigger,
pub changed_node_ids: Vec<String>,
pub changed_region_ids: Vec<RegionId>,
pub explicit_global_rebuild: bool,
}Fields
trigger: RecomputeTriggerchanged_node_ids: Vec<String>changed_region_ids: Vec<RegionId>explicit_global_rebuild: boolTrait Implementations
Sourceimpl Clone for InvalidationManifest
impl Clone for InvalidationManifest
Sourcefn clone(&self) -> InvalidationManifest
fn clone(&self) -> InvalidationManifest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InvalidationManifest
impl Debug for InvalidationManifest
Sourceimpl<'de> Deserialize<'de> for InvalidationManifest
impl<'de> Deserialize<'de> for InvalidationManifest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for InvalidationManifest
Sourceimpl JsonSchema for InvalidationManifest
impl JsonSchema for InvalidationManifest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InvalidationManifest
impl PartialEq for InvalidationManifest
Sourcefn eq(&self, other: &InvalidationManifest) -> bool
fn eq(&self, other: &InvalidationManifest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for InvalidationManifest
impl Serialize for InvalidationManifest
impl StructuralPartialEq for InvalidationManifest