pub struct NodeBelief {
pub node_id: String,
pub local_support_count: usize,
pub belief_micros: u64,
}Fields
node_id: Stringlocal_support_count: usizebelief_micros: u64Trait Implementations
Sourceimpl Clone for NodeBelief
impl Clone for NodeBelief
Sourcefn clone(&self) -> NodeBelief
fn clone(&self) -> NodeBelief
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NodeBelief
impl Debug for NodeBelief
Sourceimpl<'de> Deserialize<'de> for NodeBelief
impl<'de> Deserialize<'de> for NodeBelief
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for NodeBelief
Sourceimpl JsonSchema for NodeBelief
impl JsonSchema for NodeBelief
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for NodeBelief
impl PartialEq for NodeBelief
Sourcefn eq(&self, other: &NodeBelief) -> bool
fn eq(&self, other: &NodeBelief) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for NodeBelief
impl Serialize for NodeBelief
impl StructuralPartialEq for NodeBelief