pub struct RegionExecutionTrace {
pub region_id: RegionId,
pub region_digest: String,
pub executed_node_ids: Vec<String>,
pub witness_node_ids: Vec<String>,
pub syndrome_ids: Vec<SyndromeId>,
}Fields
region_id: RegionIdregion_digest: Stringexecuted_node_ids: Vec<String>witness_node_ids: Vec<String>syndrome_ids: Vec<SyndromeId>Trait Implementations
Sourceimpl Clone for RegionExecutionTrace
impl Clone for RegionExecutionTrace
Sourcefn clone(&self) -> RegionExecutionTrace
fn clone(&self) -> RegionExecutionTrace
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RegionExecutionTrace
impl Debug for RegionExecutionTrace
Sourceimpl<'de> Deserialize<'de> for RegionExecutionTrace
impl<'de> Deserialize<'de> for RegionExecutionTrace
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RegionExecutionTrace
Sourceimpl JsonSchema for RegionExecutionTrace
impl JsonSchema for RegionExecutionTrace
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RegionExecutionTrace
impl PartialEq for RegionExecutionTrace
Sourcefn eq(&self, other: &RegionExecutionTrace) -> bool
fn eq(&self, other: &RegionExecutionTrace) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RegionExecutionTrace
impl Serialize for RegionExecutionTrace
impl StructuralPartialEq for RegionExecutionTrace