pub struct ResidualSample {
pub iteration: u32,
pub total_residual_micros: u64,
}Fields
iteration: u32total_residual_micros: u64Trait Implementations
Sourceimpl Clone for ResidualSample
impl Clone for ResidualSample
Sourcefn clone(&self) -> ResidualSample
fn clone(&self) -> ResidualSample
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResidualSample
impl Debug for ResidualSample
Sourceimpl<'de> Deserialize<'de> for ResidualSample
impl<'de> Deserialize<'de> for ResidualSample
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ResidualSample
Sourceimpl JsonSchema for ResidualSample
impl JsonSchema for ResidualSample
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ResidualSample
impl PartialEq for ResidualSample
Sourcefn eq(&self, other: &ResidualSample) -> bool
fn eq(&self, other: &ResidualSample) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ResidualSample
impl Serialize for ResidualSample
impl StructuralPartialEq for ResidualSample