pub struct ScheduledExecution {
pub workload_class: WorkloadClass,
pub stage_kinds: Vec<SchedulerStageKind>,
pub degraded_reason: Option<String>,
pub execution: ExecutionReport,
}Fields
workload_class: WorkloadClassstage_kinds: Vec<SchedulerStageKind>degraded_reason: Option<String>execution: ExecutionReportTrait Implementations
Sourceimpl Clone for ScheduledExecution
impl Clone for ScheduledExecution
Sourcefn clone(&self) -> ScheduledExecution
fn clone(&self) -> ScheduledExecution
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScheduledExecution
impl Debug for ScheduledExecution
Sourceimpl<'de> Deserialize<'de> for ScheduledExecution
impl<'de> Deserialize<'de> for ScheduledExecution
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ScheduledExecution
Sourceimpl JsonSchema for ScheduledExecution
impl JsonSchema for ScheduledExecution
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ScheduledExecution
impl PartialEq for ScheduledExecution
Sourcefn eq(&self, other: &ScheduledExecution) -> bool
fn eq(&self, other: &ScheduledExecution) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ScheduledExecution
impl Serialize for ScheduledExecution
impl StructuralPartialEq for ScheduledExecution